client

package
v3.1.0-alpha.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2026 License: MPL-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type NodeAPI

type NodeAPI interface {
	GetNodeInfo() (*panel.NodeInfo, error)
	GetUserList() ([]panel.UserInfo, error)
	GetUserAlive() (map[int]int, error)
	ReportUserTraffic([]panel.UserTraffic) error
	ReportNodeOnlineUsers(*map[int][]string) error
	ReportNodeStatus(*monitor.SystemInfo, int, int64, int64) error
	ReportNodeLogs([]panel.NodeLogEntry) error

	GetNodeID() int
	GetAPIHost() string
	GetAPIKey() string
	GetSecret() string
	IsSignEnabled() bool
	SetNodeType(string)
	SupportsSync() bool
	Close() error
}

NodeAPI defines the contract required by node controllers regardless of transport. Implementations can be REST (api/panel) or gRPC (api/grpc).

type RuntimeHealthReporter

type RuntimeHealthReporter interface {
	ReportNodeRuntimeHealth(healthy bool, message string) error
}

RuntimeHealthReporter is implemented by transports that can report a supervised core's process health without changing the legacy heartbeat payload contract.

Jump to