agentv1pb

package
v3.1.0-alpha.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2026 License: MPL-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	AgentControlService_ControlStream_FullMethodName = "/anix.agent.v1.AgentControlService/ControlStream"
)

Variables

var (
	ObservedPhase_name = map[int32]string{
		0: "OBSERVED_PHASE_UNSPECIFIED",
		1: "OBSERVED_PHASE_ACCEPTED",
		2: "OBSERVED_PHASE_APPLYING",
		3: "OBSERVED_PHASE_SUCCEEDED",
		4: "OBSERVED_PHASE_FAILED",
		5: "OBSERVED_PHASE_SUPERSEDED",
	}
	ObservedPhase_value = map[string]int32{
		"OBSERVED_PHASE_UNSPECIFIED": 0,
		"OBSERVED_PHASE_ACCEPTED":    1,
		"OBSERVED_PHASE_APPLYING":    2,
		"OBSERVED_PHASE_SUCCEEDED":   3,
		"OBSERVED_PHASE_FAILED":      4,
		"OBSERVED_PHASE_SUPERSEDED":  5,
	}
)

Enum value maps for ObservedPhase.

var AgentControlService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "anix.agent.v1.AgentControlService",
	HandlerType: (*AgentControlServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "ControlStream",
			Handler:       _AgentControlService_ControlStream_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "api/grpc/agent/v1/agent.proto",
}

AgentControlService_ServiceDesc is the grpc.ServiceDesc for AgentControlService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_api_grpc_agent_v1_agent_proto protoreflect.FileDescriptor

Functions

func RegisterAgentControlServiceServer

func RegisterAgentControlServiceServer(s grpc.ServiceRegistrar, srv AgentControlServiceServer)

Types

type AgentControlServiceClient

type AgentControlServiceClient interface {
	ControlStream(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[AgentToControl, ControlToAgent], error)
}

AgentControlServiceClient is the client API for AgentControlService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AgentControlServiceServer

type AgentControlServiceServer interface {
	ControlStream(grpc.BidiStreamingServer[AgentToControl, ControlToAgent]) error
	// contains filtered or unexported methods
}

AgentControlServiceServer is the server API for AgentControlService service. All implementations must embed UnimplementedAgentControlServiceServer for forward compatibility.

type AgentControlService_ControlStreamClient

type AgentControlService_ControlStreamClient = grpc.BidiStreamingClient[AgentToControl, ControlToAgent]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AgentControlService_ControlStreamServer

type AgentControlService_ControlStreamServer = grpc.BidiStreamingServer[AgentToControl, ControlToAgent]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AgentToControl

type AgentToControl struct {
	RequestId    string `protobuf:"bytes,1,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	NodeId       uint32 `protobuf:"varint,2,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
	Revision     uint64 `protobuf:"varint,3,opt,name=revision,proto3" json:"revision,omitempty"`
	SentAtUnixMs int64  `protobuf:"varint,4,opt,name=sent_at_unix_ms,json=sentAtUnixMs,proto3" json:"sent_at_unix_ms,omitempty"`
	// Types that are valid to be assigned to Payload:
	//
	//	*AgentToControl_Hello
	//	*AgentToControl_Heartbeat
	//	*AgentToControl_OperationAck
	//	*AgentToControl_ObservedState
	Payload isAgentToControl_Payload `protobuf_oneof:"payload"`
	// contains filtered or unexported fields
}

func (*AgentToControl) Descriptor deprecated

func (*AgentToControl) Descriptor() ([]byte, []int)

Deprecated: Use AgentToControl.ProtoReflect.Descriptor instead.

func (*AgentToControl) GetHeartbeat

func (x *AgentToControl) GetHeartbeat() *Heartbeat

func (*AgentToControl) GetHello

func (x *AgentToControl) GetHello() *Hello

func (*AgentToControl) GetNodeId

func (x *AgentToControl) GetNodeId() uint32

func (*AgentToControl) GetObservedState

func (x *AgentToControl) GetObservedState() *ObservedState

func (*AgentToControl) GetOperationAck

func (x *AgentToControl) GetOperationAck() *OperationAck

func (*AgentToControl) GetPayload

func (x *AgentToControl) GetPayload() isAgentToControl_Payload

func (*AgentToControl) GetRequestId

func (x *AgentToControl) GetRequestId() string

func (*AgentToControl) GetRevision

func (x *AgentToControl) GetRevision() uint64

func (*AgentToControl) GetSentAtUnixMs

func (x *AgentToControl) GetSentAtUnixMs() int64

func (*AgentToControl) ProtoMessage

func (*AgentToControl) ProtoMessage()

func (*AgentToControl) ProtoReflect

func (x *AgentToControl) ProtoReflect() protoreflect.Message

func (*AgentToControl) Reset

func (x *AgentToControl) Reset()

func (*AgentToControl) String

func (x *AgentToControl) String() string

type AgentToControl_Heartbeat

type AgentToControl_Heartbeat struct {
	Heartbeat *Heartbeat `protobuf:"bytes,11,opt,name=heartbeat,proto3,oneof"`
}

type AgentToControl_Hello

type AgentToControl_Hello struct {
	Hello *Hello `protobuf:"bytes,10,opt,name=hello,proto3,oneof"`
}

type AgentToControl_ObservedState

type AgentToControl_ObservedState struct {
	ObservedState *ObservedState `protobuf:"bytes,13,opt,name=observed_state,json=observedState,proto3,oneof"`
}

type AgentToControl_OperationAck

type AgentToControl_OperationAck struct {
	OperationAck *OperationAck `protobuf:"bytes,12,opt,name=operation_ack,json=operationAck,proto3,oneof"`
}

type Capability

type Capability struct {
	Name       string            `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Version    string            `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
	Attributes map[string]string `` /* 147-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Capability) Descriptor deprecated

func (*Capability) Descriptor() ([]byte, []int)

Deprecated: Use Capability.ProtoReflect.Descriptor instead.

func (*Capability) GetAttributes

func (x *Capability) GetAttributes() map[string]string

func (*Capability) GetName

func (x *Capability) GetName() string

func (*Capability) GetVersion

func (x *Capability) GetVersion() string

func (*Capability) ProtoMessage

func (*Capability) ProtoMessage()

func (*Capability) ProtoReflect

func (x *Capability) ProtoReflect() protoreflect.Message

func (*Capability) Reset

func (x *Capability) Reset()

func (*Capability) String

func (x *Capability) String() string

type ControlToAgent

type ControlToAgent struct {
	RequestId    string `protobuf:"bytes,1,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	NodeId       uint32 `protobuf:"varint,2,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
	Revision     uint64 `protobuf:"varint,3,opt,name=revision,proto3" json:"revision,omitempty"`
	SentAtUnixMs int64  `protobuf:"varint,4,opt,name=sent_at_unix_ms,json=sentAtUnixMs,proto3" json:"sent_at_unix_ms,omitempty"`
	// Types that are valid to be assigned to Payload:
	//
	//	*ControlToAgent_HelloAck
	//	*ControlToAgent_HeartbeatAck
	//	*ControlToAgent_DesiredOperation
	Payload isControlToAgent_Payload `protobuf_oneof:"payload"`
	// contains filtered or unexported fields
}

func (*ControlToAgent) Descriptor deprecated

func (*ControlToAgent) Descriptor() ([]byte, []int)

Deprecated: Use ControlToAgent.ProtoReflect.Descriptor instead.

func (*ControlToAgent) GetDesiredOperation

func (x *ControlToAgent) GetDesiredOperation() *DesiredOperation

func (*ControlToAgent) GetHeartbeatAck

func (x *ControlToAgent) GetHeartbeatAck() *HeartbeatAck

func (*ControlToAgent) GetHelloAck

func (x *ControlToAgent) GetHelloAck() *HelloAck

func (*ControlToAgent) GetNodeId

func (x *ControlToAgent) GetNodeId() uint32

func (*ControlToAgent) GetPayload

func (x *ControlToAgent) GetPayload() isControlToAgent_Payload

func (*ControlToAgent) GetRequestId

func (x *ControlToAgent) GetRequestId() string

func (*ControlToAgent) GetRevision

func (x *ControlToAgent) GetRevision() uint64

func (*ControlToAgent) GetSentAtUnixMs

func (x *ControlToAgent) GetSentAtUnixMs() int64

func (*ControlToAgent) ProtoMessage

func (*ControlToAgent) ProtoMessage()

func (*ControlToAgent) ProtoReflect

func (x *ControlToAgent) ProtoReflect() protoreflect.Message

func (*ControlToAgent) Reset

func (x *ControlToAgent) Reset()

func (*ControlToAgent) String

func (x *ControlToAgent) String() string

type ControlToAgent_DesiredOperation

type ControlToAgent_DesiredOperation struct {
	DesiredOperation *DesiredOperation `protobuf:"bytes,12,opt,name=desired_operation,json=desiredOperation,proto3,oneof"`
}

type ControlToAgent_HeartbeatAck

type ControlToAgent_HeartbeatAck struct {
	HeartbeatAck *HeartbeatAck `protobuf:"bytes,11,opt,name=heartbeat_ack,json=heartbeatAck,proto3,oneof"`
}

type ControlToAgent_HelloAck

type ControlToAgent_HelloAck struct {
	HelloAck *HelloAck `protobuf:"bytes,10,opt,name=hello_ack,json=helloAck,proto3,oneof"`
}

type DesiredOperation

type DesiredOperation struct {
	OperationId    string `protobuf:"bytes,1,opt,name=operation_id,json=operationId,proto3" json:"operation_id,omitempty"`
	Kind           string `protobuf:"bytes,2,opt,name=kind,proto3" json:"kind,omitempty"`
	Revision       uint64 `protobuf:"varint,3,opt,name=revision,proto3" json:"revision,omitempty"`
	PayloadJson    []byte `protobuf:"bytes,4,opt,name=payload_json,json=payloadJson,proto3" json:"payload_json,omitempty"`
	DeadlineUnixMs int64  `protobuf:"varint,5,opt,name=deadline_unix_ms,json=deadlineUnixMs,proto3" json:"deadline_unix_ms,omitempty"`
	// contains filtered or unexported fields
}

func (*DesiredOperation) Descriptor deprecated

func (*DesiredOperation) Descriptor() ([]byte, []int)

Deprecated: Use DesiredOperation.ProtoReflect.Descriptor instead.

func (*DesiredOperation) GetDeadlineUnixMs

func (x *DesiredOperation) GetDeadlineUnixMs() int64

func (*DesiredOperation) GetKind

func (x *DesiredOperation) GetKind() string

func (*DesiredOperation) GetOperationId

func (x *DesiredOperation) GetOperationId() string

func (*DesiredOperation) GetPayloadJson

func (x *DesiredOperation) GetPayloadJson() []byte

func (*DesiredOperation) GetRevision

func (x *DesiredOperation) GetRevision() uint64

func (*DesiredOperation) ProtoMessage

func (*DesiredOperation) ProtoMessage()

func (*DesiredOperation) ProtoReflect

func (x *DesiredOperation) ProtoReflect() protoreflect.Message

func (*DesiredOperation) Reset

func (x *DesiredOperation) Reset()

func (*DesiredOperation) String

func (x *DesiredOperation) String() string

type Heartbeat

type Heartbeat struct {
	SessionId        string             `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	UptimeSeconds    int64              `protobuf:"varint,2,opt,name=uptime_seconds,json=uptimeSeconds,proto3" json:"uptime_seconds,omitempty"`
	ObservedRevision uint64             `protobuf:"varint,3,opt,name=observed_revision,json=observedRevision,proto3" json:"observed_revision,omitempty"`
	Metrics          map[string]float64 `` /* 143-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Heartbeat) Descriptor deprecated

func (*Heartbeat) Descriptor() ([]byte, []int)

Deprecated: Use Heartbeat.ProtoReflect.Descriptor instead.

func (*Heartbeat) GetMetrics

func (x *Heartbeat) GetMetrics() map[string]float64

func (*Heartbeat) GetObservedRevision

func (x *Heartbeat) GetObservedRevision() uint64

func (*Heartbeat) GetSessionId

func (x *Heartbeat) GetSessionId() string

func (*Heartbeat) GetUptimeSeconds

func (x *Heartbeat) GetUptimeSeconds() int64

func (*Heartbeat) ProtoMessage

func (*Heartbeat) ProtoMessage()

func (*Heartbeat) ProtoReflect

func (x *Heartbeat) ProtoReflect() protoreflect.Message

func (*Heartbeat) Reset

func (x *Heartbeat) Reset()

func (*Heartbeat) String

func (x *Heartbeat) String() string

type HeartbeatAck

type HeartbeatAck struct {
	SessionId        string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	ServerTimeUnixMs int64  `protobuf:"varint,2,opt,name=server_time_unix_ms,json=serverTimeUnixMs,proto3" json:"server_time_unix_ms,omitempty"`
	DesiredRevision  uint64 `protobuf:"varint,3,opt,name=desired_revision,json=desiredRevision,proto3" json:"desired_revision,omitempty"`
	// contains filtered or unexported fields
}

func (*HeartbeatAck) Descriptor deprecated

func (*HeartbeatAck) Descriptor() ([]byte, []int)

Deprecated: Use HeartbeatAck.ProtoReflect.Descriptor instead.

func (*HeartbeatAck) GetDesiredRevision

func (x *HeartbeatAck) GetDesiredRevision() uint64

func (*HeartbeatAck) GetServerTimeUnixMs

func (x *HeartbeatAck) GetServerTimeUnixMs() int64

func (*HeartbeatAck) GetSessionId

func (x *HeartbeatAck) GetSessionId() string

func (*HeartbeatAck) ProtoMessage

func (*HeartbeatAck) ProtoMessage()

func (*HeartbeatAck) ProtoReflect

func (x *HeartbeatAck) ProtoReflect() protoreflect.Message

func (*HeartbeatAck) Reset

func (x *HeartbeatAck) Reset()

func (*HeartbeatAck) String

func (x *HeartbeatAck) String() string

type Hello

type Hello struct {
	Protocol     string            `protobuf:"bytes,1,opt,name=protocol,proto3" json:"protocol,omitempty"`
	AgentVersion string            `protobuf:"bytes,2,opt,name=agent_version,json=agentVersion,proto3" json:"agent_version,omitempty"`
	InstanceId   string            `protobuf:"bytes,3,opt,name=instance_id,json=instanceId,proto3" json:"instance_id,omitempty"`
	Capabilities []*Capability     `protobuf:"bytes,4,rep,name=capabilities,proto3" json:"capabilities,omitempty"`
	Labels       map[string]string `` /* 139-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Hello) Descriptor deprecated

func (*Hello) Descriptor() ([]byte, []int)

Deprecated: Use Hello.ProtoReflect.Descriptor instead.

func (*Hello) GetAgentVersion

func (x *Hello) GetAgentVersion() string

func (*Hello) GetCapabilities

func (x *Hello) GetCapabilities() []*Capability

func (*Hello) GetInstanceId

func (x *Hello) GetInstanceId() string

func (*Hello) GetLabels

func (x *Hello) GetLabels() map[string]string

func (*Hello) GetProtocol

func (x *Hello) GetProtocol() string

func (*Hello) ProtoMessage

func (*Hello) ProtoMessage()

func (*Hello) ProtoReflect

func (x *Hello) ProtoReflect() protoreflect.Message

func (*Hello) Reset

func (x *Hello) Reset()

func (*Hello) String

func (x *Hello) String() string

type HelloAck

type HelloAck struct {
	SessionId                string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	ServerTimeUnixMs         int64  `protobuf:"varint,2,opt,name=server_time_unix_ms,json=serverTimeUnixMs,proto3" json:"server_time_unix_ms,omitempty"`
	HeartbeatIntervalSeconds uint32 `` /* 136-byte string literal not displayed */
	DesiredRevision          uint64 `protobuf:"varint,4,opt,name=desired_revision,json=desiredRevision,proto3" json:"desired_revision,omitempty"`
	// contains filtered or unexported fields
}

func (*HelloAck) Descriptor deprecated

func (*HelloAck) Descriptor() ([]byte, []int)

Deprecated: Use HelloAck.ProtoReflect.Descriptor instead.

func (*HelloAck) GetDesiredRevision

func (x *HelloAck) GetDesiredRevision() uint64

func (*HelloAck) GetHeartbeatIntervalSeconds

func (x *HelloAck) GetHeartbeatIntervalSeconds() uint32

func (*HelloAck) GetServerTimeUnixMs

func (x *HelloAck) GetServerTimeUnixMs() int64

func (*HelloAck) GetSessionId

func (x *HelloAck) GetSessionId() string

func (*HelloAck) ProtoMessage

func (*HelloAck) ProtoMessage()

func (*HelloAck) ProtoReflect

func (x *HelloAck) ProtoReflect() protoreflect.Message

func (*HelloAck) Reset

func (x *HelloAck) Reset()

func (*HelloAck) String

func (x *HelloAck) String() string

type ObservedPhase

type ObservedPhase int32
const (
	ObservedPhase_OBSERVED_PHASE_UNSPECIFIED ObservedPhase = 0
	ObservedPhase_OBSERVED_PHASE_ACCEPTED    ObservedPhase = 1
	ObservedPhase_OBSERVED_PHASE_APPLYING    ObservedPhase = 2
	ObservedPhase_OBSERVED_PHASE_SUCCEEDED   ObservedPhase = 3
	ObservedPhase_OBSERVED_PHASE_FAILED      ObservedPhase = 4
	ObservedPhase_OBSERVED_PHASE_SUPERSEDED  ObservedPhase = 5
)

func (ObservedPhase) Descriptor

func (ObservedPhase) Enum

func (x ObservedPhase) Enum() *ObservedPhase

func (ObservedPhase) EnumDescriptor deprecated

func (ObservedPhase) EnumDescriptor() ([]byte, []int)

Deprecated: Use ObservedPhase.Descriptor instead.

func (ObservedPhase) Number

func (ObservedPhase) String

func (x ObservedPhase) String() string

func (ObservedPhase) Type

type ObservedState

type ObservedState struct {
	OperationId      string        `protobuf:"bytes,1,opt,name=operation_id,json=operationId,proto3" json:"operation_id,omitempty"`
	Revision         uint64        `protobuf:"varint,2,opt,name=revision,proto3" json:"revision,omitempty"`
	Phase            ObservedPhase `protobuf:"varint,3,opt,name=phase,proto3,enum=anix.agent.v1.ObservedPhase" json:"phase,omitempty"`
	Message          string        `protobuf:"bytes,4,opt,name=message,proto3" json:"message,omitempty"`
	StateJson        []byte        `protobuf:"bytes,5,opt,name=state_json,json=stateJson,proto3" json:"state_json,omitempty"`
	ObservedAtUnixMs int64         `protobuf:"varint,6,opt,name=observed_at_unix_ms,json=observedAtUnixMs,proto3" json:"observed_at_unix_ms,omitempty"`
	SessionId        string        `protobuf:"bytes,7,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ObservedState) Descriptor deprecated

func (*ObservedState) Descriptor() ([]byte, []int)

Deprecated: Use ObservedState.ProtoReflect.Descriptor instead.

func (*ObservedState) GetMessage

func (x *ObservedState) GetMessage() string

func (*ObservedState) GetObservedAtUnixMs

func (x *ObservedState) GetObservedAtUnixMs() int64

func (*ObservedState) GetOperationId

func (x *ObservedState) GetOperationId() string

func (*ObservedState) GetPhase

func (x *ObservedState) GetPhase() ObservedPhase

func (*ObservedState) GetRevision

func (x *ObservedState) GetRevision() uint64

func (*ObservedState) GetSessionId

func (x *ObservedState) GetSessionId() string

func (*ObservedState) GetStateJson

func (x *ObservedState) GetStateJson() []byte

func (*ObservedState) ProtoMessage

func (*ObservedState) ProtoMessage()

func (*ObservedState) ProtoReflect

func (x *ObservedState) ProtoReflect() protoreflect.Message

func (*ObservedState) Reset

func (x *ObservedState) Reset()

func (*ObservedState) String

func (x *ObservedState) String() string

type OperationAck

type OperationAck struct {
	OperationId      string `protobuf:"bytes,1,opt,name=operation_id,json=operationId,proto3" json:"operation_id,omitempty"`
	Accepted         bool   `protobuf:"varint,2,opt,name=accepted,proto3" json:"accepted,omitempty"`
	Error            string `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
	AcceptedAtUnixMs int64  `protobuf:"varint,4,opt,name=accepted_at_unix_ms,json=acceptedAtUnixMs,proto3" json:"accepted_at_unix_ms,omitempty"`
	SessionId        string `protobuf:"bytes,5,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	Revision         uint64 `protobuf:"varint,6,opt,name=revision,proto3" json:"revision,omitempty"`
	// contains filtered or unexported fields
}

func (*OperationAck) Descriptor deprecated

func (*OperationAck) Descriptor() ([]byte, []int)

Deprecated: Use OperationAck.ProtoReflect.Descriptor instead.

func (*OperationAck) GetAccepted

func (x *OperationAck) GetAccepted() bool

func (*OperationAck) GetAcceptedAtUnixMs

func (x *OperationAck) GetAcceptedAtUnixMs() int64

func (*OperationAck) GetError

func (x *OperationAck) GetError() string

func (*OperationAck) GetOperationId

func (x *OperationAck) GetOperationId() string

func (*OperationAck) GetRevision

func (x *OperationAck) GetRevision() uint64

func (*OperationAck) GetSessionId

func (x *OperationAck) GetSessionId() string

func (*OperationAck) ProtoMessage

func (*OperationAck) ProtoMessage()

func (*OperationAck) ProtoReflect

func (x *OperationAck) ProtoReflect() protoreflect.Message

func (*OperationAck) Reset

func (x *OperationAck) Reset()

func (*OperationAck) String

func (x *OperationAck) String() string

type UnimplementedAgentControlServiceServer

type UnimplementedAgentControlServiceServer struct{}

UnimplementedAgentControlServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAgentControlServiceServer) ControlStream

type UnsafeAgentControlServiceServer

type UnsafeAgentControlServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAgentControlServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AgentControlServiceServer will result in compilation errors.

Jump to