Documentation
¶
Index ¶
- func New(c *conf.CoreConfig) (vCore.Core, error)
- type CoreDebugger
- func (d *CoreDebugger) DumpCurrentState()
- func (d *CoreDebugger) IsEnabled() bool
- func (d *CoreDebugger) LogCoreStart(coreType string, version string)
- func (d *CoreDebugger) LogCoreStop(coreType string)
- func (d *CoreDebugger) LogError(operation string, tag string, err error)
- func (d *CoreDebugger) LogInboundAdd(tag string, protocol string, port int, config interface{})
- func (d *CoreDebugger) LogInboundRemove(tag string)
- func (d *CoreDebugger) LogUserAdd(tag string, count int, users interface{})
- func (d *CoreDebugger) LogUserRemove(tag string, count int)
- func (d *CoreDebugger) LogXrayConfig(tag string, inboundConfig interface{})
- type DNSConfig
- type UserMap
- type Xray
- func (c *Xray) AddNode(tag string, info *panel.NodeInfo, config *conf.Options) error
- func (c *Xray) AddUsers(p *vCore.AddUsersParams) (added int, err error)
- func (c *Xray) Close() error
- func (c *Xray) DelNode(tag string) error
- func (c *Xray) DelUsers(users []panel.UserInfo, tag string, _ *panel.NodeInfo) error
- func (c *Xray) GetUserManager(tag string) (proxy.UserManager, error)
- func (x *Xray) GetUserTrafficSlice(tag string, reset bool) ([]panel.UserTraffic, error)
- func (c *Xray) Protocols() []string
- func (c *Xray) Start() error
- func (c *Xray) Type() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CoreDebugger ¶
type CoreDebugger struct {
// contains filtered or unexported fields
}
CoreDebugger 提供 Xray 内核调试功能
func NewCoreDebugger ¶
func NewCoreDebugger(enabled bool, outputDir string) *CoreDebugger
NewCoreDebugger 创建调试器
func (*CoreDebugger) DumpCurrentState ¶
func (d *CoreDebugger) DumpCurrentState()
DumpCurrentState 输出当前状态
func (*CoreDebugger) LogCoreStart ¶
func (d *CoreDebugger) LogCoreStart(coreType string, version string)
LogCoreStart 记录内核启动
func (*CoreDebugger) LogCoreStop ¶
func (d *CoreDebugger) LogCoreStop(coreType string)
LogCoreStop 记录内核停止
func (*CoreDebugger) LogError ¶
func (d *CoreDebugger) LogError(operation string, tag string, err error)
LogError 记录错误
func (*CoreDebugger) LogInboundAdd ¶
func (d *CoreDebugger) LogInboundAdd(tag string, protocol string, port int, config interface{})
LogInboundAdd 记录添加入站
func (*CoreDebugger) LogInboundRemove ¶
func (d *CoreDebugger) LogInboundRemove(tag string)
LogInboundRemove 记录移除入站
func (*CoreDebugger) LogUserAdd ¶
func (d *CoreDebugger) LogUserAdd(tag string, count int, users interface{})
LogUserAdd 记录添加用户
func (*CoreDebugger) LogUserRemove ¶
func (d *CoreDebugger) LogUserRemove(tag string, count int)
LogUserRemove 记录移除用户
func (*CoreDebugger) LogXrayConfig ¶
func (d *CoreDebugger) LogXrayConfig(tag string, inboundConfig interface{})
LogXrayConfig 记录完整的 Xray 配置
type DNSConfig ¶
type DNSConfig struct {
Servers []interface{} `json:"servers"`
Tag string `json:"tag"`
}
type Xray ¶
Xray Structure
func (*Xray) GetUserManager ¶
func (c *Xray) GetUserManager(tag string) (proxy.UserManager, error)
func (*Xray) GetUserTrafficSlice ¶
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package app contains the third-party app used to replace the default app in xray-core
|
Package app contains the third-party app used to replace the default app in xray-core |
|
distro
|
|
Click to show internal directories.
Click to hide internal directories.